#!/usr/bin/env python3
"""
Fix Pydantic v2 compatibility issues.
"""

import re
from pathlib import Path

def fix_root_validators(file_path: Path):
    """Fix root_validator decorators for Pydantic v2 compatibility."""
    with open(file_path, 'r') as f:
        content = f.read()
    
    # Replace @root_validator with @root_validator(skip_on_failure=True)
    # but only if it doesn't already have parameters
    pattern = r'@root_validator(?!\()'
    replacement = '@root_validator(skip_on_failure=True)'
    
    new_content = re.sub(pattern, replacement, content)
    
    if new_content != content:
        with open(file_path, 'w') as f:
            f.write(new_content)
        print(f"Fixed {file_path}")
        return True
    return False

def main():
    """Fix all Pydantic compatibility issues."""
    config_dir = Path("src/text2sql_ltm/config")
    
    files_fixed = 0
    for py_file in config_dir.glob("*.py"):
        if fix_root_validators(py_file):
            files_fixed += 1
    
    print(f"Fixed {files_fixed} files")

if __name__ == "__main__":
    main()
