"""
AI-Powered Features for Text2SQL-LTM library.

This module provides cutting-edge AI features that enhance the Text2SQL experience:
- Intelligent SQL validation and optimization
- Multi-modal query understanding (text, voice, images)
- Real-time query explanation and teaching
- Automated schema discovery and documentation
- Intelligent error recovery and suggestions
- Natural language SQL debugging
- Query performance prediction
- Automated test case generation
"""

from .sql_validator import SQLValidator, ValidationResult, OptimizationSuggestion
from .sql_optimizer import SQLOptimizer, PerformanceAnalyzer, OptimizationStrategy
from .multimodal import MultiModalProcessor, VoiceProcessor, ImageProcessor
from .explainer import SQLExplainer, ExplanationLevel, TeachingMode
from .schema_discovery import SchemaDiscovery, AutoDocumenter, SchemaInsights
from .error_recovery import ErrorRecovery, SmartSuggestions, DebugAssistant
from .performance_predictor import PerformancePredictor, QueryComplexityAnalyzer
from .test_generator import TestCaseGenerator, DataGenerator, ValidationSuite
from .query_translator import QueryTranslator, DialectConverter, CrossPlatformOptimizer
from .security_analyzer import SecurityAnalyzer, VulnerabilityScanner, SafetyChecker

__all__ = [
    # SQL Intelligence
    "SQLValidator",
    "SQLOptimizer", 
    "PerformanceAnalyzer",
    "PerformancePredictor",
    
    # Multi-modal Processing
    "MultiModalProcessor",
    "VoiceProcessor",
    "ImageProcessor",
    
    # Explanation and Teaching
    "SQLExplainer",
    "ExplanationLevel",
    "TeachingMode",
    
    # Schema Intelligence
    "SchemaDiscovery",
    "AutoDocumenter",
    "SchemaInsights",
    
    # Error Handling and Recovery
    "ErrorRecovery",
    "SmartSuggestions",
    "DebugAssistant",
    
    # Testing and Validation
    "TestCaseGenerator",
    "DataGenerator",
    "ValidationSuite",
    
    # Cross-platform Support
    "QueryTranslator",
    "DialectConverter",
    "CrossPlatformOptimizer",
    
    # Security
    "SecurityAnalyzer",
    "VulnerabilityScanner",
    "SafetyChecker",
    
    # Data Structures
    "ValidationResult",
    "OptimizationSuggestion",
    "OptimizationStrategy",
    "QueryComplexityAnalyzer",
]
